# Rest Adapter

/// admonition | Internal Functions
    type: warning
These functions are meant for use in other parts of the module. You _probably_ shouldn't be calling these manually.  
If there's an endpoint method missing from the main [FloweryAPI](flowery.md) class, you should open an [issue](https://c.csw.im/cswimr/PyFlowery/issues) (or a [pull request](https://c.csw.im/cswimr/PyFlowery/pulls)).
///

::: rest_adapter
